# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add calibration ingestion workflow

Revision ID: e99b65ee2b4e
Revises: 2ac701610fc7
Create Date: 2021-07-06 11:44:30.072590

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "e99b65ee2b4e"
down_revision = "2ac701610fc7"
branch_labels = None
depends_on = None


condor_content = """executable = ingest_cal.sh
arguments = metadata.json

output = ingest.out
error = ingest.err
log = condor.log

SBIN_PATH = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin
should_transfer_files = yes
transfer_input_files = $(SBIN_PATH)/conveyor, $(SBIN_PATH)/ingest_envoy, $(SBIN_PATH)/calibration-table-collector.sh, ./metadata.json

getenv = True
environment = "CAPO_PATH=/home/casa/capo"

queue
"""

script_content = """#!/bin/sh
set -o errexit

./conveyor --retrieve $1
./ingest_envoy --ingest-cal $1

"""


def upgrade():
    op.execute(
        """
        INSERT INTO workflows (workflow_name) VALUES ('ingest_cal')
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('ingest_cal.condor', E'{condor_content}', 'ingest_cal')
        """
    )

    op.execute(
        f"""
        INSERT INTO workflow_templates (filename, content, workflow_name)
        VALUES ('ingest_cal.sh', E'{script_content}', 'ingest_cal')
        """
    )


def downgrade():
    op.execute(
        """
        DELETE FROM workflows WHERE workflow_name='ingest-cal'
        """
    )

    op.execute(
        """
        DELETE FROM workflow_templates WHERE workflow_name='ingest-cal'
        """
    )
